@@ -1,5 +1,5 @@
 package Acme::Daily::Fail;
-$Acme::Daily::Fail::VERSION = '1.12';
+$Acme::Daily::Fail::VERSION = '1.14';
 #ABSTRACT: generate random newspaper headlines
 
 use strict;
@@ -154,7 +154,8 @@ my $objects = [
 	"the conservative party",  # FAIL
 	"cliff richard",           # Should this be in here?
 	"the memory of diana",
-	"Britain's swans"          # This always stays
+	"Britain's swans",         # This always stays
+  "Brexit",
 ];
 
 # Matches an auxiliary verb with the subject
@@ -219,7 +220,7 @@ Acme::Daily::Fail - generate random newspaper headlines
 
 =head1 VERSION
 
-version 1.12
+version 1.14
 
 =head1 SYNOPSIS
 
@@ -262,7 +263,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Chris Applegate and Chris Williams.
+This software is copyright (c) 2017 by Chris Applegate and Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
